@@ -6,6 +6,21 @@ from diningcodeapi.utils import parse_background_image_url_in_style, convert_css
 
 
 class ReviewMixin:
+    def get_reviews(self, store_code: str, page_no: int, page_size: int = 5, proxy=None):
+        if page_no == 1:
+            soup = self._request_first_page(store_code, proxy)
+        else:
+            soup = self._request_more_than_second_page(store_code, page_no, page_size, proxy)
+
+        review_tags = soup.find_all("div", class_="latter-graph")
+        reviews = []
+        for review_tag in review_tags:
+            review = self._parse_review(review_tag)
+            reviews.append(review)
+
+        return reviews
+
+
     def _parse_review(self, review_tag_soup):
         id = review_tag_soup.attrs['id']
 
@@ -72,8 +87,8 @@ class ReviewMixin:
 
         return result
 
-    def _request_first_page(self, store_code):
-        response = requests.post(f'https://www.diningcode.com/profile.php?rid={store_code}', headers=HEADERS)
+    def _request_first_page(self, store_code, proxy=None):
+        response = requests.post(f'https://www.diningcode.com/profile.php?rid={store_code}', headers=HEADERS, proxies={"http":proxy})
         response.raise_for_status()
         soup = BeautifulSoup(response.text, 'html.parser')
         container_tag = soup.find('div', id='div_review')
@@ -95,16 +110,3 @@ class ReviewMixin:
         soup = BeautifulSoup(response.text, 'html.parser')
         return soup
 
-    def get_reviews(self, store_code: str, page_no: int, page_size: int = 5, proxy=None):
-        if page_no == 1:
-            soup = self._request_first_page(store_code)
-        else:
-            soup = self._request_more_than_second_page(store_code, page_no, page_size)
-
-        review_tags = soup.find_all("div", class_="latter-graph")
-        reviews = []
-        for review_tag in review_tags:
-            review = self._parse_review(review_tag)
-            reviews.append(review)
-
-        return reviews
